@@ -1,6 +1,6 @@
 from enum import Enum
 
-from lightning_hpo.loggers.logger import Logger
+from lightning_hpo.loggers.logger import Logger, NoneLogger
 from lightning_hpo.loggers.streamlit.streamlit import StreamLitLogger
 from lightning_hpo.loggers.tensorboard import TensorboardLogger
 from lightning_hpo.loggers.wandb import WandbLogger
@@ -10,8 +10,11 @@ class LoggerType(Enum):
     STREAMLIT = "streamlit"
     WANDB = "wandb"
     TENSORBOARD = "tensorboard"
+    NONE = "none"
 
     def get_logger(self) -> Logger:
+        if self == LoggerType.NONE:
+            return NoneLogger()
         if self == LoggerType.STREAMLIT:
             return StreamLitLogger()
         elif self == LoggerType.WANDB:
