@@ -4,12 +4,19 @@ from pathlib import Path
 from time import time
 from typing import Any, Dict, Optional
 
-import pytorch_lightning
+from lightning_hpo.utilities.imports import _IS_PYTORCH_LIGHTNING_AVAILABLE
+
+if _IS_PYTORCH_LIGHTNING_AVAILABLE:
+    import pytorch_lightning
+    from pytorch_lightning.loggers import TensorBoardLogger
+else:
+    import lightning.pytorch as pytorch_lightning
+    from lightning.pytorch.loggers import TensorBoardLogger
+
 from fsspec.implementations.local import LocalFileSystem
 from lightning import LightningFlow
 from lightning.app.storage import Drive
-from lightning.pytorch.loggers import TensorBoardLogger
-from lightning_app.storage.path import filesystem
+from lightning.app.storage.path import _filesystem
 
 from lightning_hpo.loggers.logger import Logger
 
@@ -34,7 +41,7 @@ class DriveTensorBoardLogger(TensorBoardLogger):
         super().finalize(status)
 
     def _upload_to_storage(self):
-        fs = filesystem()
+        fs = _filesystem()
         fs.invalidate_cache()
 
         source_path = Path(self.log_dir).resolve()
